#
# spec file for package python-cheetah
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?rhel} && 0%{?rhel} <= 6
%{!?py_ver:     %define py_ver     %(python -c "import sys; v=sys.version_info[:2]; print '%%d.%%d'%%v" 2>/dev/null || echo PYTHON-NOT-FOUND)}
%{!?py_prefix:  %define py_prefix  %(python -c "import sys; print sys.prefix" 2>/dev/null || echo PYTHON-NOT-FOUND)}
%{!?py_libdir:  %define py_libdir  %{py_prefix}/%{_lib}/python%{py_ver}}
%{!?py_incdir:  %define py_incdir  %{py_prefix}/include/python%{py_ver}}
%{!?py_sitedir: %define py_sitedir %{py_libdir}/site-packages}
%endif

%define modname cheetah

Name:           python-%{modname}
Version:        2.2.2
Release:        1.3
Summary:        Python-Powered Template Engine
Url:            http://www.cheetahtemplate.org/
License:        Other uncritical OpenSource License
Group:          Development/Libraries/Python
Source:         Cheetah-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1030
%{py_requires}
%endif
BuildRequires:  python-devel

%description
Cheetah is a template engine and code generation tool, written in
Python. Web development is its principle use, but Cheetah is very
flexible and is also being used to generate C++ game code, Java, sql,
form emails and even Python code.

Authors: Tavis Rudd <cheetahtemplate-discuss@lists.sf.net>



%prep
%setup -q -n Cheetah-%{version}

%build
export CFLAGS="$RPM_OPT_FLAGS"
python setup.py build

%install
%if 0%{?suse_version} >= 1030
python setup.py install --prefix=%{_prefix} --root=$RPM_BUILD_ROOT --record-rpm=INSTALLED_FILES
#%fdupes %buildroot
%else
python setup.py install --prefix=%{_prefix} --root=$RPM_BUILD_ROOT
%endif

%clean
rm -rf %{buildroot}

%if 0%{?suse_version} >= 1030

%files -f INSTALLED_FILES
%else

%files
%endif
%defattr(-,root,root)
%doc CHANGES LICENSE README TODO
%if !0%{?suse_version}
%{_bindir}/*
%{py_sitedir}/*
%endif

%changelog
* Wed Feb  9 2011 ro@suse.de
- overhaul python macro usage
* Tue Feb  8 2011 ma@novell.com
- fix specfile
* Tue Feb  1 2011 mc@suse.de
- fix build for RH
* Tue Sep 15 2009 jfunk@funktronics.ca
- Update to 2.2.2
  - Prevent _namemapper.c from segfaulting when PyImport_ImportModule fails
    for some reason (Bogdano Arendartchuk <debogdano@gmail.com>)
  - Removal of the contrib/markdown module (in favor of a setuptools
    dependency)
  - Default setup.py to use setuptools by default, failing that, fall back to
    distutils
  - Improvements to setup.py to support building for Windows (thanks abbeyj!)
  - Improvements to C-based NameMapper for Windows
  - Fixes for a swath of unit tests on Windows
  - Re-enabling the EOL tests (whoops)
  - Fix for unicode/utf-8 dynamic compilation error (thanks mikeb!)
    (Test.Unicode.JBQ_UTF8_Test8)
  - 0000010: [Templates] Failure to execute templates on Google App Engine
    (rtyler)
  - 0000026: [Compiler] Support multiple inheritance (rtyler)
- 2.2.1 (June 1st, 2009)
  - 0000020: [Templates] Builtin support for using Cheetah with Django
    (rtyler)
  - 0000021: [Compiler] @static and @classmethod don't properly define the
    _filter local (rtyler)
  - 0000023: [Compiler] Update Template super calls to use super() (rtyler)
  - Update all references to communitycheetah.org to point back at
    cheetahtemplate.org
- 2.2.0 (May 17th, 2009)
  - Switch all internal representations of template code to unicode objects
    instead of str() objects
  - Convert unicode compiled template to an utf8 char buffer when writing to a
    file (Jean-Baptiste Quenot <jbq@caraldi.com>)
  - 0000011: [Templates] Calling a function with arguments calls the function
    with None (rtyler)
  - 0000015: [Tests] Resolve test failures in 'next' branch (rtyler)
  - 0000019: [Templates] Properly warn when joining unicode and non-unicode
    objects in DummyTransaction (rtyler)
- 2.1.2 (May 5, 2009)
  - 0000006: [Templates] Support @staticmethod and @classmethod (rtyler)
- 2.1.1 (April 16, 2009)
  - Support __eq__() and __ne__() the way you might expect in
    src/Tools/RecursiveNull (patch suggested by Peter Warasin
    <peter@endian.com>)
  - Applied patch to avoid hitting the filesystem to get the file modification
    time everytime a #include directive is processed (Jean-Baptiste Quenot
    <jbq@caraldi.com>)
  - Applied patch to fix some annoying cases when Cheetah writes to stderr
    instead of propagating the exception (Jean-Baptiste Quenot
    <jbq@caraldi.com>)
  - Added KDE editor support
  - Applied patch to correct importHook behavior on Python 2.6
    (reported/patched by Toshio Ernie Kuratomi <a.badger@gmail.com>)
  - Correct unicode issue when calling/embedding unicode templates inside of
    other templtes (testcase Tests.Unicode.JPQ_UTF8_Test3. reported by
    Jean-Baptiste Quenot <jbq@caraldi.com>)
  - Added --shbang option (e.g. "cheetah compile --shbang
    '#!/usr/bin/python2.6' ")
  - Removed dependency on optik OptionParser in favor of builtin Python
    optparse module
  - Introduction of the #transform directive for whole-document filtering
  - Introduction of Cheetah.contrib.markdown and Cheetah.Filters.Markdown for
    outputting a markdown processed template (meant for #transform)
  - Cheetah.Filters.CodeHighlighter, pygments-based code highlighting filter
    for use with #transform
  - Addition of "useLegacyImportMode" compiler setting (defaulted to True) to
    allow for older (read: broken) import behavior
- 2.1.0.1 (March 27, 2009)
  - Fix inline import issue introduced in v2.1.0
- 2.1.0 (March 16, 2009)
  - Quiet DeprecationWarnings being printed to stderr when using Cheetah on
    Python 2.6 and up. Patch suggested by Satoru SATOH
    <satoru.satoh@gmail.com>
  - Apply patch to support parallel compilation of templates courtesy of Evan
    Klitzke <evan@eklitzke.org>
  - Corrected issue when __getattr__ calls on searchList objects raise
    exceptions (tyler@slide.com)
  - make autocalling in valueForName correctly ignore newstyle classes and
    instances that are callable, as it does for oldstyle classes and
    instances. Patch from lucas@endian.com [TR]
  - made it possible to chain multiple decorators to a method #def [TR with
    patch from Graham Dennis]
  - fixed a bug in _eatMultiLineDef that Graham Dennis reported. [TR]
  - fixed 'module.__init__() argument 1 must be string, not unicode' bug in
    Template.py reported by Erwin Ambrosch [TR]
* Fri Nov 14 2008 @gmail.com> - 2.0.1-2
- replaced --record with --record-rpm as per bnc#441794
* Tue Feb 12 2008 Peter Poeml <poeml@suse.de> - 2.0.1-1
- update to 2.0.1
* Sat Nov 25 2006 James Oakley <jfunk@funktronics.ca> - 2.0-1
- Initial release
